==> StanfordParser-1.3.tar.gz: lexparser-2003-09-06/src/edu/stanford/nlp/trees/MemorySentencebank.java <==
package edu.stanford.nlp.trees;

import java.io.*;
import java.util.*;

import edu.stanford.nlp.util.*;

/**
 * A <code>MemorySentencebank</code> object stores a corpus of examples with
 * given sentence structures in memory (as a Collection)
 * @author Christopher Manning
 * @version Jan 2000
 */
public final class MemorySentencebank extends Sentencebank implements FileProcessor {

    /** The collection of parse sentences 
     */
    private ArrayList parseSentences;


    /** Create a new sentence bank.
     */
    public MemorySentencebank() {
	this(new SimpleSentenceReaderFactory());
    }

    
    /** Create a new sentence bank.
     *	@param srf the factory class to be called to create a new
     *  <code>SentenceReader</code>
     */
    public MemorySentencebank(SentenceReaderFactory srf) {
	super(srf);
	parseSentences = new ArrayList();
    }

    
    /** Create a new Sentencebank.
     *	@param initialCapacity The initial size of the underlying Collection,
     *  (if a Collection-based storage mechanism is being provided)
     */
    public MemorySentencebank(int initialCapacity) {
	this(initialCapacity, new SimpleSentenceReaderFactory());
    }


    /** Create a new sentence bank.
     *	@param initialCapacity The initial size of the underlying Collection
     *	@param srf the factory class to be called to create a new
     *  <code>SentenceReader</code>
     */
    public MemorySentencebank(int initialCapacity, SentenceReaderFactory srf) {
	super(initialCapacity, srf);
	parseSentences = new ArrayList(initialCapacity);
    }
    

    /** Empty a <code>Sentencebank</code>.
     */
    public void clear() {
	parseSentences.clear();
    }


    /** Load sentences from given directory.
     * @param path  file or directory to load from
     * @param filter a FilenameFilter of files to load
     */
    public void loadPath(File path, FileFilter filt) {
	FilePathProcessor.processPath(path, filt, this);
    }


    /** Load a collection of parse sentences from the file of given name.
     *  Each sentence may optionally be encased in parens to allow for Penn
     *  Sentencebank style sentences.
     *  This methods implements the <code>FileProcessor</code> interface.
     *  @param file file to load a sentence from
     */
    public void processFile(File file) {
	SentenceReader sr = null;
	Sentence pt;

	try {
	    // maybe print file name to stdout to get some feedback
	    if (Dbg.PROGRESS) {
		System.err.println(file);
	    }
	    // could throw an IO exception if can't open for reading
	    sr = sentenceReaderFactory().newSentenceReader(new BufferedReader(
						    new FileReader(file)));
	    while ((pt = sr.readSentence()) != null) {
		parseSentences.add(pt);
	    }
	} catch (IOException e) {
	    System.err.println("loadSentence IO Exception" + e);
	} finally {
	    try { 
		if (sr != null) {
		    sr.close();  // important: closes file even if error!
		}
	    } catch (IOException e) {
	    }
	}
    }


    /** Get a sentence by index from the Sentencebank.
     */
    public Object get(int i) {
	return parseSentences.get(i);
    }


    /** Apply the SentenceVisitor sp to all sentences in the Sentencebank
     */
    public void apply(SentenceVisitor sp) {
	for (int i = 0; i < parseSentences.size(); i++) {
	    sp.visitSentence((Sentence) parseSentences.get(i));
	}
	// or could do as Iterator but slower
	// Iterator iter = parseSentences.iterator();
	// while (iter.hasNext()) {
	//    sp.processSentence((Sentence) iter.next());
	// }
    }


    /** Return an Iterator over Sentences in the Sentencebank
     */
    public Iterator iterator() {
	return parseSentences.iterator();
    }


    /** Returns the size of the Sentencebank.
     *  Provides a more efficient implementation than the one for a
     *  generic <code>Sentencebank</code>
     *  @return the number of trees in the Sentencebank
     */
    public int size() {
	return parseSentences.size();
    }


    /** Loads sentencebank grammar from first argument and print it.
     * @param args array of command-line arguments
     */
    public static void main(String[] args) {
	Timing.startTime();
	Sentencebank sentencebank = new MemorySentencebank(new 
						   SentenceReaderFactory() {
	    public SentenceReader newSentenceReader(Reader in) {
	        return new SentenceReader(in, new TaggedWordFactory(),
					  new PennSentenceNormalizer(),
					  new PennTagbankStreamTokenizer(in));
	    }
	});
	sentencebank.loadPath(args[0]);
	Timing.endTime();
	System.out.println(sentencebank);

	System.out.println();
	System.out.println("This Sentencebank contains "
			   + sentencebank.size() + " sentences.");

    }

}

==> StanfordParser-1.4.tar.gz: lexparser-2004-03-24/src/edu/stanford/nlp/trees/MemorySentencebank.java <==
package edu.stanford.nlp.trees;

import java.io.*;
import java.util.*;

import edu.stanford.nlp.util.*;

/**
 * A <code>MemorySentencebank</code> object stores a corpus of examples with
 * given sentence structures in memory (as a Collection)
 * @author Christopher Manning
 * @version Jan 2000
 */
public final class MemorySentencebank extends Sentencebank
        implements FileProcessor {

    private static final boolean PRINT_FILENAMES = false;

    /** The collection of parse sentences 
     */
    private ArrayList parseSentences;


    /** Create a new sentence bank.
     */
    public MemorySentencebank() {
	this(new SimpleSentenceReaderFactory());
    }

    
    /** Create a new sentence bank.
     *	@param srf the factory class to be called to create a new
     *  <code>SentenceReader</code>
     */
    public MemorySentencebank(SentenceReaderFactory srf) {
	super(srf);
	parseSentences = new ArrayList();
    }

    
    /** Create a new Sentencebank.
     *	@param initialCapacity The initial size of the underlying Collection,
     *  (if a Collection-based storage mechanism is being provided)
     */
    public MemorySentencebank(int initialCapacity) {
	this(initialCapacity, new SimpleSentenceReaderFactory());
    }


    /** Create a new sentence bank.
     *	@param initialCapacity The initial size of the underlying Collection
     *	@param srf the factory class to be called to create a new
     *  <code>SentenceReader</code>
     */
    public MemorySentencebank(int initialCapacity, SentenceReaderFactory srf) {
	super(initialCapacity, srf);
	parseSentences = new ArrayList(initialCapacity);
    }
    

    /** Empty a <code>Sentencebank</code>.
     */
    public void clear() {
	parseSentences.clear();
    }


    /** Load sentences from given directory.
     * @param path  file or directory to load from
     * @param filter a FilenameFilter of files to load
     */
    public void loadPath(File path, FileFilter filt) {
	FilePathProcessor.processPath(path, filt, this);
    }


    /** Load a collection of parse sentences from the file of given name.
     *  Each sentence may optionally be encased in parens to allow for Penn
     *  Sentencebank style sentences.
     *  This methods implements the <code>FileProcessor</code> interface.
     *  @param file file to load a sentence from
     */
    public void processFile(File file) {
	SentenceReader sr = null;
	Sentence pt;

	try {
	    // maybe print file name to stdout to get some feedback
	    if (PRINT_FILENAMES) {
		System.err.println(file);
	    }
	    // could throw an IO exception if can't open for reading
	    sr = sentenceReaderFactory().newSentenceReader(new BufferedReader(
						    new FileReader(file)));
	    while ((pt = sr.readSentence()) != null) {
		parseSentences.add(pt);
	    }
	} catch (IOException e) {
	    System.err.println("loadSentence IO Exception" + e);
	} finally {
	    try { 
		if (sr != null) {
		    sr.close();  // important: closes file even if error!
		}
	    } catch (IOException e) {
	    }
	}
    }


    /** Get a sentence by index from the Sentencebank.
     */
    public Object get(int i) {
	return parseSentences.get(i);
    }


    /** Apply the SentenceVisitor sp to all sentences in the Sentencebank
     */
    public void apply(SentenceVisitor sp) {
	for (int i = 0; i < parseSentences.size(); i++) {
	    sp.visitSentence((Sentence) parseSentences.get(i));
	}
	// or could do as Iterator but slower
	// Iterator iter = parseSentences.iterator();
	// while (iter.hasNext()) {
	//    sp.processSentence((Sentence) iter.next());
	// }
    }


    /** Return an Iterator over Sentences in the Sentencebank
     */
    public Iterator iterator() {
	return parseSentences.iterator();
    }


    /** Returns the size of the Sentencebank.
     *  Provides a more efficient implementation than the one for a
     *  generic <code>Sentencebank</code>
     *  @return the number of trees in the Sentencebank
     */
    public int size() {
	return parseSentences.size();
    }


    /** Loads sentencebank grammar from first argument and print it.
     * @param args array of command-line arguments
     */
    public static void main(String[] args) {
	Timing.startTime();
	Sentencebank sentencebank = new MemorySentencebank(new 
						   SentenceReaderFactory() {
	    public SentenceReader newSentenceReader(Reader in) {
	        return new SentenceReader(in, new TaggedWordFactory(),
					  new PennSentenceNormalizer(),
					  new PennTagbankStreamTokenizer(in));
	    }
	});
	sentencebank.loadPath(args[0]);
	Timing.endTime();
	System.out.println(sentencebank);

	System.out.println();
	System.out.println("This Sentencebank contains "
			   + sentencebank.size() + " sentences.");

    }

}
